==> haskell-knob-0.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: knob
version: 0.1.1
id: knob-0.1.1-6AwOopXXtH5D2ybHerSGDf
key: knob-0.1.1-6AwOopXXtH5D2ybHerSGDf
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/knob/
synopsis: Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.
    .
    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)
category: System
abi: 4143e6a42c497cc8749303dff7fa89dc
exposed: True
exposed-modules:
    Data.Knob
import-dirs: /usr/lib/ghc-8.4.3/site-local/knob-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/knob-0.1.1
hs-libraries: HSknob-0.1.1-6AwOopXXtH5D2ybHerSGDf
depends:
    base-4.11.1.0 bytestring-0.10.8.2 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html: /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-knob-0.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: knob
version: 0.1.1
id: knob-0.1.1-LtuT8HtMVvKDK08pQbEL0Y
key: knob-0.1.1-LtuT8HtMVvKDK08pQbEL0Y
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/knob/
synopsis: Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.
    .
    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)
category: System
abi: b8013dfcdda9736f9fab849fe90f72d2
exposed: True
exposed-modules:
    Data.Knob
import-dirs: /usr/lib/ghc-8.6.1/site-local/knob-0.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/knob-0.1.1
hs-libraries: HSknob-0.1.1-LtuT8HtMVvKDK08pQbEL0Y
depends:
    base-4.12.0.0 bytestring-0.10.8.2 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html: /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
